// { dg-do compile }
// 1999-06-23 bkoz 

// Copyright (C) 1999, 2001, 2003 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
// USA.

// extension headers

// This should include a list of all headers in the extension
// subdirectory that are meant to be directly included.

#include <ext/algorithm>
#include <ext/functional>
#include <ext/hash_map>
#include <ext/hash_set>
#include <ext/iterator>
#include <ext/memory>
#include <ext/numeric>
#include <ext/rb_tree>
#include <ext/rope>
#include <ext/slist>
#include <ext/debug_allocator.h>
#include <ext/malloc_allocator.h>
#include <ext/new_allocator.h>
#include <ext/array_allocator.h>
#include <ext/mt_allocator.h>
#include <ext/pool_allocator.h>
#include <ext/stdio_filebuf.h>
#include <ext/stdio_sync_filebuf.h>

